@@ -291,6 +291,12 @@ class ss:
         check_status(lib.GxB_Matrix_memoryUsage(size, self._parent._carg), self._parent)
         return size[0]
 
+    @property
+    def is_iso(self):
+        is_iso = ffi_new("bool*")
+        check_status(lib.GxB_Matrix_iso(is_iso, self._parent._carg), self._parent)
+        return is_iso[0]
+
     @property
     def format(self):
         # Determine current format
@@ -1095,8 +1101,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(indptr)
         unclaim_buffer(col_indices)
         unclaim_buffer(values)
@@ -1272,8 +1276,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(indptr)
         unclaim_buffer(row_indices)
         unclaim_buffer(values)
@@ -1470,8 +1472,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(indptr)
         unclaim_buffer(rows)
         unclaim_buffer(col_indices)
@@ -1668,8 +1668,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(indptr)
         unclaim_buffer(cols)
         unclaim_buffer(row_indices)
@@ -1850,8 +1848,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(bitmap)
         unclaim_buffer(values)
         return matrix
@@ -2030,8 +2026,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(bitmap)
         unclaim_buffer(values)
         return matrix
@@ -2182,8 +2176,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(values)
         return matrix
 
@@ -2333,8 +2325,6 @@ class ss:
             matrix._ncols = ncols
         else:
             check_status(status, matrix)
-        matrix._nrows = matrix.nrows  # XXX: sometimes changes shape!
-        matrix._ncols = matrix.ncols  # XXX: is this a bug in SuiteSparse:GraphBLAS?
         unclaim_buffer(values)
         return matrix
 
@@ -2457,7 +2447,7 @@ class ss:
         name=None,
     ):
         """
-        GxB_Matrix_pack_XXX
+        GxB_Matrix_pack_xxx
 
         `pack_any` is like `import_any` except it "packs" data into an
         existing Matrix.  This is the opposite of ``unpack()``
