@@ -74,6 +74,12 @@ class ss:
         check_status(lib.GxB_Vector_memoryUsage(size, self._parent._carg), self._parent)
         return size[0]
 
+    @property
+    def is_iso(self):
+        is_iso = ffi_new("bool*")
+        check_status(lib.GxB_Vector_iso(is_iso, self._parent._carg), self._parent)
+        return is_iso[0]
+
     @property
     def format(self):
         parent = self._parent
@@ -416,7 +422,7 @@ class ss:
         name=None,
     ):
         """
-        GxB_Vector_pack_XXX
+        GxB_Vector_pack_xxx
 
         `pack_any` is like `import_any` except it "packs" data into an
         existing Vector.  This is the opposite of ``unpack()``
