@@ -15,7 +15,7 @@ _ALL_INDICES = _AllIndices()
 
 
 class IndexerResolver:
-    __slots__ = "obj", "indices"
+    __slots__ = "obj", "indices", "__weakref__"
 
     def __init__(self, obj, indices):
         self.obj = obj
@@ -62,22 +62,54 @@ class IndexerResolver:
             if index >= size:
                 raise IndexError(f"index={index}, size={size}")
             return _CScalar(int(index)), None
-        if typ is slice:
+        if typ is list:
+            pass
+        elif typ is slice:
             if index == slice(None) or index == slice(0, None):
                 # [:] means all indices; use special GrB_ALL indicator
                 return _ALL_INDICES, _CScalar(size)
-            index = tuple(range(size)[index])
+            index = list(range(size)[index])
         elif typ is np.ndarray:
             if len(index.shape) != 1:
                 raise TypeError(f"Invalid number of dimensions for index: {len(index.shape)}")
             if not np.issubdtype(index.dtype, np.integer):
                 raise TypeError(f"Invalid dtype for index: {index.dtype}")
             return _CArray(index), _CScalar(len(index))
-        elif typ is not list:
+        else:
+            from .scalar import Scalar
+
+            if typ is Scalar:
+                if index.dtype.name.startswith("F"):
+                    raise TypeError(f"An integer is required for indexing.  Got: {index.dtype}")
+                return _CScalar(index), None
+
+            from .vector import Vector
+            from .matrix import Matrix, TransposedMatrix
+
+            if typ is Vector or typ is Matrix:
+                raise TypeError(
+                    f"Invalid type for index: {typ.__name__}.\n"
+                    f"If you want to apply a mask, perhaps do something like "
+                    f"`x.dup(mask={index.name}.S)`.\n"
+                    f"If you want to assign with a mask, perhaps do something like "
+                    f"`x(mask={index.name}.S) << value`."
+                )
+            elif typ is TransposedMatrix:
+                raise TypeError(f"Invalid type for index: {typ.__name__}.")
             try:
-                index = tuple(index)
+                index = list(index)
             except Exception:
-                raise TypeError("Unable to convert to tuple")
+                from .mask import Mask
+
+                if isinstance(index, Mask):
+                    raise TypeError(
+                        f"Invalid type for index: {typ.__name__}.\n"
+                        f"If you want to apply a mask, perhaps do something like "
+                        f"`x.dup(mask={index.name})`.\n"
+                        f"If you want to assign with a mask, perhaps do something like "
+                        f"`x(mask={index.name}) << value`."
+                    )
+                raise TypeError(f"Invalid type for index: {typ}; unable to convert to list")
         return _CArray(index), _CScalar(len(index))
 
     def get_index(self, dim):
@@ -89,7 +121,7 @@ class IndexerResolver:
 
 
 class Assigner:
-    __slots__ = "updater", "resolved_indexes", "is_submask"
+    __slots__ = "updater", "resolved_indexes", "is_submask", "__weakref__"
 
     def __init__(self, updater, resolved_indexes, *, is_submask):
         # We could check here whether mask dimensions match index dimensions.
@@ -116,7 +148,7 @@ class Assigner:
 
 
 class AmbiguousAssignOrExtract:
-    __slots__ = "parent", "resolved_indexes"
+    __slots__ = "parent", "resolved_indexes", "__weakref__"
 
     def __init__(self, parent, resolved_indexes):
         self.parent = parent
@@ -243,7 +275,7 @@ class AmbiguousAssignOrExtract:
 
 
 class Updater:
-    __slots__ = "parent", "kwargs"
+    __slots__ = "parent", "kwargs", "__weakref__"
 
     def __init__(self, parent, **kwargs):
         self.parent = parent
@@ -301,7 +333,7 @@ class Updater:
 
 
 class InfixExprBase:
-    __slots__ = "left", "right"
+    __slots__ = "left", "right", "__weakref__"
 
     def __init__(self, left, right):
         self.left = left
